@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2015-12-25'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,6 +66,7 @@ sub _add_prereqs_from_func_meta {
     }
 
     # from x.schema.{entity,element_entity} & x.completion (cli script only)
+    # from x.perl.coerce_from and x.coerce_from in argument schema's attributes
     {
         last unless $is_cli;
         my $args = $meta->{args};
@@ -91,6 +92,21 @@ sub _add_prereqs_from_func_meta {
                 die "x.element_completion must be an array" unless ref($e) eq 'ARRAY';
                 $self->_add_prereq("Perinci::Sub::XCompletion::$e->[0]"=>0);
             }
+
+            my $sch = $arg_spec->{'schema'};
+            if ($sch) {
+                my $type = $sch->[0];
+                $e = $sch->[1]{'x.coerce_from'};
+                if ($e) {
+                    $self->_add_prereq("Data::Sah::Coerce::perl::$type\::$_"=>0)
+                        for @$e;
+                }
+                $e = $sch->[1]{'x.perl.coerce_from'};
+                if ($e) {
+                    $self->_add_prereq("Data::Sah::Coerce::perl::$type\::$_"=>0)
+                        for @$e;
+                }
+            }
         }
     }
 
@@ -178,7 +194,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.07 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-12-25.
+This document describes version 0.08 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-05-20.
 
 =head1 SYNOPSIS
 
@@ -227,10 +243,6 @@ to corresponding C<Perinci::Sub::XCompletion::NAME>.
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<Rinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-Rinci-AddPrereqs>.
@@ -247,13 +259,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
